<?php
namespace MascotCoreNovioElementor;

/**
 * Class Plugin
 *
 * Main Plugin class
 * @since 1.2.0
 */
class Plugin {

	/**
	 * Instance
	 *
	 * @since 1.2.0
	 * @access private
	 * @static
	 *
	 * @var Plugin The single instance of the class.
	 */
	private static $_instance = null;

	/**
	 * Instance
	 *
	 * Ensures only one instance of the class is loaded or can be loaded.
	 *
	 * @since 1.2.0
	 * @access public
	 *
	 * @return Plugin An instance of the class.
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	/**
	 * widget_scripts
	 *
	 * Load required plugin core files.
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function widget_scripts() {
		wp_register_script( 'mascot-core-hellojs', plugins_url( '/assets/js/hello-world.js', __FILE__ ), [ 'jquery' ], false, true );
	}

	/**
	 * Include Widgets files
	 *
	 * Load widgets files
	 *
	 * @since 1.2.0
	 * @access private
	 */
	private function include_widgets_files() {


		//cpt
		require_once( __DIR__ . '/cpt/clients/clients.php' );
		require_once( __DIR__ . '/cpt/gallery/gallery.php' );
		require_once( __DIR__ . '/cpt/projects/projects.php' );
		require_once( __DIR__ . '/cpt/services/services.php' );
		require_once( __DIR__ . '/cpt/staff/staff.php' );
		require_once( __DIR__ . '/cpt/testimonials/testimonials.php' );

		//Give Campaign
		require_once( __DIR__ . '/widgets/give-campaigns/give-campaigns.php' );
		require_once( __DIR__ . '/widgets/give-single-form-custom/give-single-form-custom.php' );

		//shortcodes
		require_once( __DIR__ . '/widgets/animated-layers/animated-layers.php' );
		require_once( __DIR__ . '/widgets/button/button.php' );
		require_once( __DIR__ . '/widgets/before-after-slider/before-after-slider.php' );
		require_once( __DIR__ . '/widgets/blog/blog.php' );
		require_once( __DIR__ . '/widgets/countdown-timer/countdown-timer.php' );
		require_once( __DIR__ . '/widgets/dropcaps/dropcaps.php' );
		require_once( __DIR__ . '/widgets/features-box/features-box.php' );
		require_once( __DIR__ . '/widgets/floating-objects/floating-objects.php' );
		require_once( __DIR__ . '/widgets/funfact-counter/funfact-counter.php' );
		require_once( __DIR__ . '/widgets/icon-box/icon-box.php' );
		require_once( __DIR__ . '/widgets/image-with-rotated-text/image-with-rotated-text.php' );
		require_once( __DIR__ . '/widgets/opening-hours/opening-hours.php' );
		require_once( __DIR__ . '/widgets/opening-hours-compressed/opening-hours-compressed.php' );
		require_once( __DIR__ . '/widgets/paroller-animation/paroller-animation.php' );
		require_once( __DIR__ . '/widgets/pie-chart/pie-chart.php' );
		require_once( __DIR__ . '/widgets/pricing-table/pricing-table.php' );
		require_once( __DIR__ . '/widgets/progress-bar/progress-bar.php' );
		require_once( __DIR__ . '/widgets/section-title/section-title.php' );
		require_once( __DIR__ . '/widgets/social-links/social-links.php' );
		require_once( __DIR__ . '/widgets/unordered-list/unordered-list.php' );

	}

	/**
	 * Register Widgets
	 *
	 * Register new Elementor widgets.
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files();

		//cpt
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\TM_Elementor_Clients() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\TM_Elementor_Gallery() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\TM_Elementor_Projects() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\TM_Elementor_Services() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\TM_Elementor_Staff() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\TM_Elementor_Testimonials() );

		//Give Campaign
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\TM_Elementor_Give_Campaigns() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\TM_Elementor_Give_Single_Campaign() );

		//shortcodes
		// Register Widgets
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\TM_Elementor_Animated_Layers() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\TM_Elementor_Before_After_Slider() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\TM_Elementor_Blog() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\TM_Elementor_Button() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\TM_Elementor_Countdown_Timer() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\TM_Elementor_Dropcaps() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\TM_Elementor_Features_Box() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\TM_Elementor_Floating_Objects() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\TM_Elementor_Funfact_Counter() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\TM_Elementor_Iconbox() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\TM_Elementor_Image_With_Rotated_Text() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\TM_Elementor_Opening_Hours() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\TM_Elementor_Opening_Hours_Compressed() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\TM_Elementor_Paroller_Animation() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\TM_Elementor_Pie_Chart() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\TM_Elementor_Pricing_Table() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\TM_Elementor_Progress_Bar() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\TM_Elementor_Section_Title() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\TM_Elementor_Social_Links() );
		\Elementor\Plugin::instance()->widgets_manager->register( new Widgets\TM_Elementor_Unordered_List() );
	}

	/**
	 *  Plugin class constructor
	 *
	 * Register plugin action hooks and filters
	 *
	 * @since 1.2.0
	 * @access public
	 */
	public function __construct() {

		// Register widget scripts
		add_action( 'elementor/frontend/after_register_scripts', [ $this, 'widget_scripts' ] );

		// Register widgets
		add_action( 'elementor/widgets/register', [ $this, 'register_widgets' ] );
	}
}

// Instantiate Plugin Class
Plugin::instance();

//elementor elements
require_once( __DIR__ . '/elementor-elements/loader.php' );