<?php
namespace MascotCoreNovioElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class TM_Elementor_Funfact_Counter extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'tm-ele-funfact-counter';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Funfact Counter', 'mascot-core-elementor' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'tm' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'mascot-core-hellojs' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {

		$this->start_controls_section(
			'general',
			[
				'label' => esc_html__( 'General', 'mascot-core-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'custom_css_class',
			[
				'label' => esc_html__( "Custom CSS class", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
			]
		);
		$this->add_control(
			'design_style',
			[
				'label' => esc_html__( "Design Style", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'style1' => esc_html__( 'Default', 'mascot-core-elementor' ),
					'style2' => esc_html__( 'Style 2 -Icon Left', 'mascot-core-elementor' ),
				],
				'default' => 'style1'
			]
		);
		$this->add_control(
			'apply_current_style',
			[
				'label' => esc_html__( "Apply Current Theme CSS Style", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
		$this->add_control(
			'counter_position',
			[
				'label' => esc_html__( "Counter Positioning", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'default' => esc_html__( 'Icon - Title - Counter', 'mascot-core-elementor' ),
					'icon_counter_title' => esc_html__( 'Icon - Counter - Title', 'mascot-core-elementor' ),
				],
				'default' => 'icon_counter_title'
			]
		);
		$this->add_control(
			'title',
			[
				'label' => esc_html__( "Title", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
        'default' => esc_html__( "This is a title", 'mascot-core-elementor' ),
			]
		);
		$this->add_control(
			'content',
			[
				'label' => esc_html__( "Paragraph", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::WYSIWYG,
				'default' => ''
			]
		);
		$this->end_controls_section();



		$this->start_controls_section(
			'icon_options',
			[
				'label' => esc_html__( 'Icon Options', 'mascot-core-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'icon_type',
			[
				'label' => esc_html__( "Icon Type", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'no-icon' => esc_html__( 'No Icon', 'mascot-core-elementor' ),
					'font-icon' => esc_html__( 'Font Icon', 'mascot-core-elementor' ),
					'image' => esc_html__( 'JPG/PNG Image', 'mascot-core-elementor' ),
				],
				'default' => 'no-icon'
			]
		);
		//image
    $this->add_control(
        'image_icon',
        [
            'label' => esc_html__( "Upload Image Icon", 'mascot-core-elementor' ),
            'type' => \Elementor\Controls_Manager::MEDIA,
            'condition' => [
                'icon_type' => array('image')
            ]
        ]
    );
    $this->add_control(
        'image_icon_predefined_image_size',
        [
            'label' => esc_html__( "Choose Predefined Image Size", 'mascot-core-elementor' ),
            'type' => \Elementor\Controls_Manager::SELECT,
            'options' => mascot_core_novio_elementor_get_available_image_sizes(),
            'default' => 'full',
            'condition' => [
                'icon_type' => array('image')
            ]
        ]
    );
    $this->add_control(
        'image_icon_custom_size',
        [
            'label' => esc_html__( "Image Custom Width (Only number)", 'mascot-core-elementor' ),
            'type' => \Elementor\Controls_Manager::TEXT,
            "description" => esc_html__( "Put custom width of the uploaded image in positive integer value. Example: 120", 'mascot-core-elementor' ),
            'condition' => [
                'icon_type' => array('image')
            ]
        ]
    );



    //font icon
    //collect icon pack
    if( function_exists('novio_mascot_get_elementor_icon_pack_array') ) {
      novio_mascot_get_elementor_icon_pack_array($this);
    }


    $this->add_control(
        'icon_custom_font_size',
        [
            'label' => esc_html__( "Icon Custom Font Size", 'mascot-core-elementor' ),
            'type' => \Elementor\Controls_Manager::TEXT,
            'condition' => [
                'icon_type' => array('font-icon')
            ]
        ]
    );
    $this->add_control(
        'icon_line_height',
        [
            'label' => esc_html__( "Icon Line Height", 'mascot-core-elementor' ),
            'type' => \Elementor\Controls_Manager::TEXT,
            'condition' => [
                'icon_type' => array('font-icon')
            ]
        ]
    );
    $this->add_control(
        'icon_padding_around',
        [
            'label' => esc_html__( "Padding Around Icon/Image", 'mascot-core-elementor' ),
            'type' => \Elementor\Controls_Manager::TEXT,
            'condition' => [
                'icon_type' => array('font-icon')
            ]
        ]
    );
    $this->add_control(
        'icon_theme_colored',
        [
            'label' => esc_html__( "Make Icon Theme Colored?", 'mascot-core-elementor' ),
            'type' => \Elementor\Controls_Manager::SELECT,
            'options' => novio_mascot_theme_color_list(),
            'default' => '',
            'condition' => [
                'icon_type' => array('font-icon')
            ]
        ]
    );
    $this->add_control(
        'icon_custom_color',
        [
            'label' => esc_html__( "Icon Custom Color", 'mascot-core-elementor' ),
            'type' => \Elementor\Controls_Manager::COLOR,
            'condition' => [
                'icon_type' => array('font-icon')
            ]
        ]
    );
		$this->end_controls_section();



		$this->start_controls_section(
			'counter_options',
			[
				'label' => esc_html__( 'Counter Options', 'mascot-core-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'counter_custom_css_class',
			[
				'label' => esc_html__( "Counter Custom CSS Class", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
			]
		);
		$this->add_control(
			'counter_range',
			[
				'label' => esc_html__( "Counting Value/Number", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'description'	=> esc_html__( 'Enter number for counter without any special character. Default: 1250', 'mascot-core-elementor' ),
				'default' => esc_html__( "1250", 'mascot-core-elementor' )
			]
		);
		$this->add_control(
			'counter_prefix',
			[
				'label' => esc_html__( "Counting Value Prefix", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( "Add an Unit Symbol to the Right of Percent Value", 'mascot-core-elementor' ),
			]
		);
		$this->add_control(
			'counter_postfix',
			[
				'label' => esc_html__( "Counting Value Postfix", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
			]
		);
		$this->add_control(
			'counter_duration',
			[
				'label' => esc_html__( "Counter Duration(ms)", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'description'	=> esc_html__( 'Default: 1500', 'mascot-core-elementor' ),
				'default' => '1500'
			]
		);
		$this->add_control(
			'counter_tag',
			[
				'label'   => esc_html__( 'Counter Tag', 'mascot-core-elementor' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
				'default' => 'no',
        'options' => novio_mascot_heading_tag_list(),
        'default' => 'h2'
			]
		);
    $this->add_control(
      'counter_theme_colored',
      [
          'label' => esc_html__( "Make Icon Theme Colored?", 'mascot-core-elementor' ),
          'type' => \Elementor\Controls_Manager::SELECT,
          'options' => novio_mascot_theme_color_list(),
          'default' => '',
          'condition' => [
              'icon_type' => array('font-icon')
          ]
      ]
    );
		$this->add_control(
			'counter_text_color',
			[
				'label' => esc_html__( "Counter Text Custom Color", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'description' => '',
			]
		);
		$this->add_control(
			'counter_font_size',
			[
				'label' => esc_html__( "Font Size", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'description' => '',
			]
		);
		$this->add_control(
			'counter_line_height',
			[
				'label' => esc_html__( "Line Height", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
			]
		);
		$this->add_control(
			'counter_letter_spacing',
			[
				'label' => esc_html__( "Letter Spacing", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
			]
		);
		$this->add_control(
			'counter_font_style',
			[
				'label'   => esc_html__( 'Font Style', 'mascot-core-elementor' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
        'options' => mascot_core_novio_elementor_font_style_list(),
			]
		);
		$this->add_control(
			'counter_font_weight',
			[
				'label'   => esc_html__( 'Font Weight', 'mascot-core-elementor' ),
				'type'    => \Elementor\Controls_Manager::SELECT,
        'options' => mascot_core_novio_elementor_font_weight_list(),
			]
		);
		$this->end_controls_section();



		$this->start_controls_section(
			'title_options',
			[
				'label' => esc_html__( 'Title Options', 'mascot-core-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'title_custom_css_class',
			[
				'label' => esc_html__( "Title Custom CSS Class", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( "To style Title", 'mascot-core-elementor' ),
			]
		);
		$this->add_control(
			'title_tag',
			[
				'label' => esc_html__( "Title Tag", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
        'options' => novio_mascot_heading_tag_list(),
        'default' => 'h4'
			]
		);
		$this->add_control(
			'title_theme_colored',
			[
				'label' => esc_html__( "Title Text Theme Colored?", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
        'options' => novio_mascot_theme_color_list(),
				'default' => ''
			]
		);
		$this->add_control(
			'title_text_color',
			[
				'label' => esc_html__( "Title Text Custom Color", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => '#ef1e25'
			]
		);
		$this->add_control(
			'title_font_size',
			[
				'label' => esc_html__( "Font Size", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => ''
			]
		);
		$this->add_control(
			'title_line_height',
			[
				'label' => esc_html__( "Line Height", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => ''
			]
		);
		$this->add_control(
			'title_letter_spacing',
			[
				'label' => esc_html__( "Letter Spacing", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => ''		]
			);
		$this->add_control(
			'title_font_style',
			[
				'label' => esc_html__( "Font Style", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
        'options' => mascot_core_novio_elementor_font_style_list(),
				'default' => ''
			]
		);
		$this->add_control(
			'title_font_weight',
			[
				'label' => esc_html__( "Font Weight", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
        'options' => mascot_core_novio_elementor_font_weight_list(),
				'options' => '',
				'default' => ''
			]
		);
		$this->add_control(
			'title_text_transform',
			[
				'label' => esc_html__( "Text Transform", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
        'options' => mascot_core_novio_elementor_text_transform_list(),
				'default' => ''
			]
		);
		$this->end_controls_section();



		$this->start_controls_section(
			'content_options',
			[
				'label' => esc_html__( 'Content Options', 'mascot-core-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'text_alignment',
			[
				'label' => esc_html__( "Text Alignment", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
        'options' => novio_mascot_redux_text_alignment_list(),
				'default' => ''
			]
		);
		$this->add_control(
			'show_icon_image',
			[
				'label' => esc_html__( "Show Icon/Image", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'default' => 'yes'
			]
		);
		$this->add_control(
			'show_counter',
			[
				'label' => esc_html__( "Show Counter", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'default' => 'yes'
			]
		);
		$this->add_control(
			'show_title',
			[
				'label' => esc_html__( "Show Title", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'default' => 'yes'
			]
		);
		$this->add_control(
			'show_paragraph',
			[
				'label' => esc_html__( "Show Paragraph", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'default' => 'no'
			]
		);
		$this->end_controls_section();

	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();

		//classes
		$classes = array();

		if( $settings['text_alignment'] ) {
			$classes[] = $settings['text_alignment'];
		}
		$classes[] = $settings['custom_css_class'];
		if( $settings['apply_current_style'] ) {
			$classes[] = 'funfact-current-style';
		}
		$settings['classes'] = $classes;


		if( $settings['icon_theme_colored'] ) {
			$settings['icon_theme_colored'] = ' text-theme-colored' . $settings['icon_theme_colored'];
		}
		if( $settings['counter_theme_colored'] ) {
			$settings['counter_theme_colored'] = ' text-theme-colored' . $settings['counter_theme_colored'];
		}
		if( $settings['title_theme_colored'] ) {
			$settings['title_theme_colored'] = ' text-theme-colored' . $settings['title_theme_colored'];
		}


		$settings['title_inline_css'] = novio_mascot_get_inline_css( novio_mascot_sc_funfact_counter_title_css( $settings ) );
		$settings['counter_inline_css'] = novio_mascot_get_inline_css( novio_mascot_sc_funfact_counter_css( $settings ) );
    $settings['icon_child_inline_css'] = novio_mascot_get_inline_css( novio_mascot_sc_funfact_icon_child_css( $settings ) );


		$settings['animation_duration'] = novio_mascot_get_inline_attributes( $settings['counter_duration'], 'data-animation-duration' );


		//counter classes
		$counter_classes = array();
		$counter_classes[] = $settings['counter_custom_css_class'];
		$settings['counter_classes'] = $counter_classes;

		//title classes
		$title_classes = array();
		$title_classes[] = $settings['title_custom_css_class'];
		$settings['title_classes'] = $title_classes;


		wp_register_script( 'jquery-animatenumbers', MASCOT_CORE_TEMPLATE_URI . '/assets/js/plugins/jquery.animatenumbers.min.js', array('jquery'), false, true );
		wp_enqueue_script( 'jquery-animatenumbers' );
    $settings['settings'] = $settings;

		//Produce HTML version by using the parameters (filename, variation, folder name, parameters, shortcode_ob_start)
		$html = mascot_core_novio_elementor_get_shortcode_template_part( 'funfact-counter', $settings['design_style'], 'funfact-counter/tpl', $settings, true );

		echo $html;
	}
}
