<?php
namespace MascotCoreNovioElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class TM_Elementor_Iconbox extends Widget_Base {

  /**
   * Retrieve the widget name.
   *
   * @since 1.0.0
   *
   * @access public
   *
   * @return string Widget name.
   */
  public function get_name() {
    return 'tm-ele-iconbox';
  }

  /**
   * Retrieve the widget title.
   *
   * @since 1.0.0
   *
   * @access public
   *
   * @return string Widget title.
   */
  public function get_title() {
    return __( 'Icon Box', 'mascot-core-elementor' );
  }

  /**
   * Retrieve the widget icon.
   *
   * @since 1.0.0
   *
   * @access public
   *
   * @return string Widget icon.
   */
  public function get_icon() {
    return 'eicon-posts-ticker';
  }

  /**
   * Retrieve the list of categories the widget belongs to.
   *
   * Used to determine where to display the widget in the editor.
   *
   * Note that currently Elementor supports only one category.
   * When multiple categories passed, Elementor uses the first one.
   *
   * @since 1.0.0
   *
   * @access public
   *
   * @return array Widget categories.
   */
  public function get_categories() {
    return [ 'tm' ];
  }

  /**
   * Retrieve the list of scripts the widget depended on.
   *
   * Used to set scripts dependencies required to run the widget.
   *
   * @since 1.0.0
   *
   * @access public
   *
   * @return array Widget scripts dependencies.
   */
  public function get_script_depends() {
    return [ 'mascot-core-hellojs' ];
  }

  /**
   * Register the widget controls.
   *
   * Adds different input fields to allow the user to change and customize the widget settings.
   *
   * @since 1.0.0
   *
   * @access protected
   */
  protected function register_controls() {


      $this->start_controls_section(
          'general',
          [
            'label' => esc_html__( 'General', 'mascot-core-elementor' ),
            'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
          ]
      );

      $this->add_control(
          'link_icon_title',
          [
            'label' => esc_html__( "Link Icon, Title and Button?", 'mascot-core-elementor' ),
            'type' => \Elementor\Controls_Manager::SWITCHER,
            'default' => 'no',
          ]
      );

      $this->add_control(
          'link',
          [
            'label' => esc_html__( "Link URL", 'mascot-core-elementor' ),
            'type' => \Elementor\Controls_Manager::URL,
            'show_external' => true,
            'default' => [
              'url' => '',
              'is_external' => true,
              'nofollow' => true,
            ],
            'condition' => [
                'link_icon_title' => array('yes')
            ]
          ]
      );
      $this->add_control(
          'content',
          [
            'label' => esc_html__( "Paragraph", 'mascot-core-elementor' ),
            "description" => esc_html__( "It will be displayed above/under title", 'mascot-core-elementor' ),
            'type' => \Elementor\Controls_Manager::WYSIWYG,
            'default' => esc_html__( "Write a short description, that will describe the title or something informational and useful.", 'mascot-core-elementor' ),
          ]
      );

      $this->end_controls_section();





      $this->start_controls_section(
          'icon_section',
          [
            'label' => esc_html__( 'Icon Type', 'mascot-core-elementor' ),
            'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
          ]
      );
      $this->add_control(
          'icon_custom_css_class',
          [
            'label' => esc_html__( "Icon Custom CSS Class", 'mascot-core-elementor' ),
            'type' => \Elementor\Controls_Manager::TEXT,
          ]
      );
      $this->add_control(
          'icon_type',
          [
            'label' => esc_html__( "Icon Type", 'mascot-core-elementor' ),
            'type' => \Elementor\Controls_Manager::SELECT,
            'options' => [
                'no-icon' => esc_html__( 'No Icon', 'mascot-core-elementor' ),
                'font-icon' => esc_html__( 'Font Icon', 'mascot-core-elementor' ),
                'image' => esc_html__( 'JPG/PNG Image', 'mascot-core-elementor' ),
                'svg-image' => esc_html__( 'SVG Image', 'mascot-core-elementor' ),
            ],
            'default' => 'no-icon'
          ]
      );


      //image
      $this->add_control(
          'image_icon',
          [
              'label' => esc_html__( "Upload Image Icon", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::MEDIA,
              'condition' => [
                  'icon_type' => array('image')
              ]
          ]
      );
      $this->add_control(
          'image_icon_predefined_image_size',
          [
              'label' => esc_html__( "Choose Predefined Image Size", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SELECT,
              'options' => mascot_core_novio_elementor_get_available_image_sizes(),
              'default' => 'full',
              'condition' => [
                  'icon_type' => array('image')
              ]
          ]
      );
      $this->add_control(
          'image_icon_custom_size',
          [
              'label' => esc_html__( "Image Custom Width (Only number)", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXT,
              "description" => esc_html__( "Put custom width of the uploaded image in positive integer value. Example: 120", 'mascot-core-elementor' ),
              'condition' => [
                  'icon_type' => array('image')
              ]
          ]
      );

      //svg image
      $this->add_control(
          'svg_source_code',
          [
              'label' => esc_html__( "SVG Image Source Code", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXTAREA,
              "description" => esc_html__( "Put SVG image code here", 'mascot-core-elementor' ),
              'condition' => [
                  'icon_type' => array('svg-image')
              ]
          ]
      );
      $this->add_control(
          'svg_animation_type',
          [
              'label' => esc_html__( "SVG Animation type", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SELECT,
              'options' => [
                  'delayed' => esc_html__( 'Delayed start', 'mascot-core-elementor' ),
                  'sync'  => esc_html__( 'Syncronous', 'mascot-core-elementor' ),
                  'oneByOne'  => esc_html__( 'One By One', 'mascot-core-elementor' ),
              ],
              'default' => 'delayed',
              'condition' => [
                  'icon_type' => array('svg-image')
              ]
          ]
      );
      $this->add_control(
          'svg_animation_delay',
          [
              'label' => esc_html__( "SVG Animation Delay in ms", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXT,
              "description" => esc_html__( "Time between the drawing of first and last path, in frames (only for delayed animations)", 'mascot-core-elementor' ),
              'default' => '30',
              'condition' => [
                  'icon_type' => array('svg-image')
              ]
          ]
      );
      $this->add_control(
          'svg_animation_duration',
          [
              'label' => esc_html__( "SVG Animation Duration", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXT,
              "description" => esc_html__( "Time between the drawing of first and last path, in frames (only for delayed animations)", 'mascot-core-elementor' ),
              'default' => '200',
              'condition' => [
                  'icon_type' => array('svg-image')
              ]
          ]
      );
      $this->add_control(
          'svg_height',
          [
              'label' => esc_html__( "SVG Height", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXT,
              'condition' => [
                  'icon_type' => array('svg-image')
              ]
          ]
      );
      $this->add_control(
          'svg_width',
          [
              'label' => esc_html__( "SVG Width", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXT,
              'condition' => [
                  'icon_type' => array('svg-image')
              ]
          ]
      );
      $this->add_control(
          'svg_container_width',
          [
              'label' => esc_html__( "SVG Image Container Width(in px). Example: 100px", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXT,
              'condition' => [
                  'icon_type' => array('svg-image')
              ]
          ]
      );
      $this->add_control(
          'svg_stroke_color',
          [
              'label' => esc_html__( "SVG Stroke Color", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::COLOR,
              'condition' => [
                  'icon_type' => array('svg-image')
              ]
          ]
      );
      $this->add_control(
          'svg_stroke_width',
          [
              'label' => esc_html__( "SVG Stroke Width (px)", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXT,
              'condition' => [
                  'icon_type' => array('svg-image')
              ]
          ]
      );



      //font icon
      //collect icon pack
      if( function_exists('novio_mascot_get_elementor_icon_pack_array') ) {
        novio_mascot_get_elementor_icon_pack_array($this);
      }


      $this->add_control(
          'icon_custom_font_size',
          [
              'label' => esc_html__( "Icon Custom Font Size", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXT,
              'condition' => [
                  'icon_type' => array('font-icon')
              ]
          ]
      );
      $this->add_control(
          'icon_line_height',
          [
              'label' => esc_html__( "Icon Line Height", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXT,
              'condition' => [
                  'icon_type' => array('font-icon')
              ]
          ]
      );
      $this->add_control(
          'icon_padding_around',
          [
              'label' => esc_html__( "Padding Around Icon/Image", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXT,
              'condition' => [
                  'icon_type' => array('font-icon')
              ]
          ]
      );
      $this->add_control(
          'icon_theme_colored',
          [
              'label' => esc_html__( "Make Icon Theme Colored?", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SELECT,
              'options' => novio_mascot_theme_color_list(),
              'default' => '',
              'condition' => [
                  'icon_type' => array('font-icon')
              ]
          ]
      );
      $this->add_control(
          'icon_custom_color',
          [
              'label' => esc_html__( "Icon Custom Color", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::COLOR,
              'condition' => [
                  'icon_type' => array('font-icon')
              ]
          ]
      );
      $this->end_controls_section();










      $this->start_controls_section(
          'icon_styling',
          [
              'label' => esc_html__( 'Icon Styling', 'mascot-core-elementor' ),
              'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
          ]
      );
      $this->add_control(
          'icon_position',
          [
              'label' => esc_html__( "Icon Position", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SELECT,
              'options' => [
                  'icon-top' => esc_html__( 'Top', 'mascot-core-elementor' ),
                  'icon-left'  => esc_html__( 'Left', 'mascot-core-elementor' ),
                  'icon-right'  => esc_html__( 'Right', 'mascot-core-elementor' ),
              ],
              'default' => 'icon-top',
          ]
      );
      $this->add_control(
          'animate_icon_on_hover',
          [
              'label' => esc_html__( "Animate Icon on Hover", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SELECT,
              'options' => [
                '' => esc_html__( 'None', 'mascot-core-elementor' ),
                'rotate' => esc_html__( 'Rotate', 'mascot-core-elementor' ),
                'rotate-x' => esc_html__( 'Rotate X', 'mascot-core-elementor' ),
                'rotate-y' => esc_html__( 'Rotate Y', 'mascot-core-elementor' ),
                'translate'  => esc_html__( 'Translate', 'mascot-core-elementor' ),
                'translate-x'  => esc_html__( 'Translate X', 'mascot-core-elementor' ),
                'translate-y'  => esc_html__( 'Translate Y', 'mascot-core-elementor' ),
                'scale'  => esc_html__( 'Scale', 'mascot-core-elementor' ),
              ],
              'default' => '',
          ]
      );
      $this->add_control(
          'icon_hanging_on_top',
          [
              'label' => esc_html__( "Icon Hanging On Top?", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SWITCHER,
              'condition' => [
                  'icon_position' => array('icon-top')
              ]
          ]
      );
      $this->add_control(
          'icon_hanging_custom_margin_top',
          [
              'label' => esc_html__( "Custom Margin Top", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXT,
              "description" => esc_html__( "Custom Margin Top to Position Hanging Icon Accurately", 'mascot-core-elementor' ),
              'condition' => [
                  'icon_hanging_on_top' => array('yes')
              ]
          ]
      );

      $this->add_control(
          'icon_size',
          [
              'label' => esc_html__( "Predefined Icon/Image Size", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SELECT,
              'options' => [
                'icon-size-default' => esc_html__( 'Default', 'mascot-core-elementor' ),
                'icon-sm' => esc_html__( 'Small', 'mascot-core-elementor' ),
                'icon-xs' => esc_html__( 'Extra Small', 'mascot-core-elementor' ),
                'icon-md' => esc_html__( 'Medium', 'mascot-core-elementor' ),
                'icon-lg' => esc_html__( 'Large', 'mascot-core-elementor' ),
                'icon-xl' => esc_html__( 'Extra Large', 'mascot-core-elementor' )
              ]
          ]
      );
      $this->add_control(
          'icon_box_width',
          [
              'label' => esc_html__( "Icon/Image Area Width", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXT,
          ]
      );
      $this->add_control(
          'icon_box_height',
          [
              'label' => esc_html__( "Icon/Image Area Height", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXT,
          ]
      );
      $this->add_control(
          'icon_color',
          [
              'label' => esc_html__( "Icon/Image Area Background Color", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SELECT,
              'options' => [
                'icon-default'  =>  esc_html__( 'Default', 'mascot-core-elementor' ),
                'icon-white'  =>  esc_html__( 'White Background', 'mascot-core-elementor' ),
                'icon-gray' =>  esc_html__( 'Gray Background', 'mascot-core-elementor' ),
                'icon-dark' =>  esc_html__( 'Dark Background', 'mascot-core-elementor' )
              ],
              'default' => 'icon-default',
          ]
      );
      $this->add_control(
          'icon_area_custom_bg_color',
          [
              'label' => esc_html__( "Icon/Image Area Custom Background Color", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::COLOR,
          ]
      );
      $this->add_control(
          'icon_style',
          [
              'label' => esc_html__( "Icon/Image Area Style", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SELECT,
              'options' => [
                'icon-default'  =>  esc_html__( 'Default', 'mascot-core-elementor' ),
                'icon-rounded'  =>  esc_html__( 'Rounded', 'mascot-core-elementor' ),
                'icon-circled'  =>  esc_html__( 'Circled', 'mascot-core-elementor' ),
              ],
              'default' => 'icon-default',
          ]
      );
      $this->add_control(
          'icon_border_style',
          [
              'label' => esc_html__( "Make Icon/Image Area Bordered?", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SWITCHER,
          ]
      );
      $this->add_control(
          'icon_box_shadow',
          [
              'label' => esc_html__( "Box Shadow Around Icon Area?", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SWITCHER,
          ]
      );

      $this->end_controls_section();




      $this->start_controls_section(
          'title_section',
          [
              'label' => esc_html__( 'Title Options', 'mascot-core-elementor' ),
              'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
          ]
      );
      $this->add_control(
          'title_custom_css_class',
          [
              'label' => esc_html__( "Title Custom CSS Class", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXT,
          ]
      );
      $this->add_control(
          'title',
          [
              'label' => esc_html__( "Title", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXT,
              'default' => esc_html__( "This is a section title", 'mascot-core-elementor' ),
          ]
      );
      $this->add_control(
          'title_tag',
          [
              'label' => esc_html__( "Title Tag", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SELECT,
              'options' => novio_mascot_heading_tag_list(),
              'default' => 'h3'
          ]
      );
      $this->add_control(
          'title_text_color',
          [
              'label' => esc_html__( "Text Color", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::COLOR,
          ]
      );
      $this->add_control(
          'title_font_size',
          [
              'label' => esc_html__( "Font Size", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXT,
          ]
      );
      $this->add_control(
          'title_line_height',
          [
              'label' => esc_html__( "Line Height", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXT,
          ]
      );
      $this->add_control(
          'title_letter_spacing',
          [
              'label' => esc_html__( "Letter Spacing", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXT,
          ]
      );
      $this->add_control(
          'title_font_style',
          [
              'label' => esc_html__( "Font Style", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SELECT,
              'options' => mascot_core_novio_elementor_font_style_list(),
          ]
      );
      $this->add_control(
          'title_font_weight',
          [
              'label' => esc_html__( "Font Weight", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SELECT,
              'options' => mascot_core_novio_elementor_font_weight_list(),
          ]
      );
      $this->add_control(
          'title_text_transform',
          [
              'label' => esc_html__( "Text Transform", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SELECT,
              'options' => mascot_core_novio_elementor_text_transform_list(),
          ]
      );
      $this->end_controls_section();











      // Add predefined developer tab content for each shortcode element
      $this->start_controls_section(
          'box_styling',
          [
              'label' => esc_html__( 'Icon Box Style', 'mascot-core-elementor' ),
              'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
          ]
      );
      $this->add_control(
          'iconbox_style',
          [
              'label' => esc_html__( "Icon Box Style", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SELECT,
              'options' => [
                'icon-default'  =>  esc_html__( 'Default', 'mascot-core-elementor' ),
                'iconbox-current-theme-style1'  =>  esc_html__( 'Current Theme Style 1', 'mascot-core-elementor' ),
              ],
          ]
      );
      $this->add_control(
          'text_alignment',
          [
              'label' => esc_html__( "Text Alignment", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SELECT,
              'options' => novio_mascot_redux_text_alignment_list(),
          ]
      );
      $this->add_control(
          'box_animation',
          [
              'label' => esc_html__( "Box Animation Style", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SELECT,
              'options' => [
                ''  =>  esc_html__( 'No Animation', 'mascot-core-elementor' ),
                'iconbox-style1-current-theme-animation'  =>  esc_html__( 'Style 1 - Current Theme Animation', 'mascot-core-elementor' ),
                'iconbox-style2-border-bottom'  =>  esc_html__( 'Style 2 - Border Bottom', 'mascot-core-elementor' ),
                'iconbox-style3-moving-border-bottom' =>  esc_html__( 'Style 3 - Moving Border Bottom', 'mascot-core-elementor' ),
                'iconbox-style4-bgcolor'  =>  esc_html__( 'Style 4 - Hover BG Color', 'mascot-core-elementor' ),
                'iconbox-style5-moving-bgcolor' =>  esc_html__( 'Style 5 - Hover Moving BG Color', 'mascot-core-elementor' ),
                'iconbox-style6-moving-double-bgcolor'  =>  esc_html__( 'Style 6 - Hover Moving Double BG Color', 'mascot-core-elementor' ),
                'iconbox-style7-hover-moving-border'  =>  esc_html__( 'Style 7 - Hover Moving Border Around Box', 'mascot-core-elementor' ),
              ],
              'default' => '',
          ]
      );
      $this->add_control(
          'add_bg_img_on_hover',
          [
              'label' => esc_html__( "Add Background Image on Hover?", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SWITCHER,
              'default' => 'no',
          ]
      );
      $this->add_control(
          'bg_img_on_hover',
          [
              'label' => esc_html__( "Background Image", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::MEDIA,
              'condition' => [
                  'add_bg_img_on_hover' => array('yes')
              ]
          ]
      );
      $this->add_control(
          'make_bg_img_always_visible',
          [
              'label' => esc_html__( "Make Background Image Always Visible?", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SWITCHER,
              'condition' => [
                  'add_bg_img_on_hover' => array('yes')
              ]
          ]
      );
      $this->add_control(
          'box_shadow',
          [
              'label' => esc_html__( "Box Shadow?", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SWITCHER,
          ]
      );
      $this->add_control(
          'box_shadow_on_hover',
          [
              'label' => esc_html__( "Box Shadow only on Hover?", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SWITCHER,
          ]
      );
      $this->add_control(
          'box_default_padding',
          [
              'label' => esc_html__( "Add Default Padding Around the Box?", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SWITCHER,
          ]
      );
      $this->add_control(
          'everything_centered_in_responsive',
          [
              'label' => esc_html__( "Make everything centered in responsive mode?", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SWITCHER,
          ]
      );
      $this->add_control(
          'title_mt_0_in_desktop',
          [
              'label' => esc_html__( "Make title margin top = 0 in desktop mode?", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SWITCHER,
          ]
      );
      $this->add_control(
          'iconbox_hover_move_up_animation',
          [
              'label' => esc_html__( "Animate Move Up on Hover?", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SWITCHER,
          ]
      );
      $this->add_control(
          'iconbox_border_radius',
          [
              'label' => esc_html__( "Add Border Radius Around the Box?", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SWITCHER,
          ]
      );
      $this->end_controls_section();












      $this->start_controls_section(
          'button_options',
          [
              'label' => esc_html__( 'Button Options', 'mascot-core-elementor' ),
              'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
          ]
      );
      mascot_core_novio_elementor_get_viewdetails_button_arraylist($this, 1);
      mascot_core_novio_elementor_get_viewdetails_button_arraylist($this, 2);
      mascot_core_novio_elementor_get_button_arraylist($this, 1);
      mascot_core_novio_elementor_get_button_arraylist($this, 2);
      mascot_core_novio_elementor_get_button_arraylist($this, 3);
      mascot_core_novio_elementor_get_button_arraylist($this, 4);
      mascot_core_novio_elementor_get_button_arraylist($this, 5);
      mascot_core_novio_elementor_get_button_arraylist($this, 6);
      mascot_core_novio_elementor_get_button_arraylist($this, 7);
      mascot_core_novio_elementor_get_button_arraylist($this, 8);
      mascot_core_novio_elementor_get_button_arraylist($this, 9);
      mascot_core_novio_elementor_get_button_arraylist($this, 10);
      mascot_core_novio_elementor_get_button_arraylist($this, 11);
      $this->end_controls_section();







      // Add predefined developer tab content for each shortcode element
      $this->start_controls_section(
          'developer_tools',
          [
              'label' => esc_html__( 'Developer Tools', 'mascot-core-elementor' ),
              'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
          ]
      );

      $this->add_control(
          'shortcode_snippet',
          [
              'label'   => esc_html__( 'Show Shortcode Snippet', 'mascot-core-elementor' ),
              'type'    => \Elementor\Controls_Manager::SELECT,
              'default' => 'no',
              'options' => array(
                  'no'  => esc_html__( 'No', 'mascot-core-elementor' ),
                  'yes' => esc_html__( 'Yes', 'mascot-core-elementor' ),
              ),
          ]
      );


      $this->end_controls_section();
  }

  /**
   * Render the widget output on the frontend.
   *
   * Written in PHP and used to generate the final HTML.
   *
   * @since 1.0.0
   *
   * @access protected
   */
  protected function render() {
    $settings = $this->get_settings_for_display();


    //link url
    $settings['target'] = ( $settings['link'] && $settings['link']['is_external'] ) ? ' target="_blank"' : '';
    $settings['url'] = ( $settings['link'] && $settings['link']['url'] ) ? $settings['link']['url'] : '';



    //classes
    $classes = array();

    if( $settings['icon_type'] ) {
      $classes[] = 'tm-iconbox-icontype-' . $settings['icon_type'];
    }
    if( $settings['iconbox_style'] ) {
      $classes[] = $settings['iconbox_style'];
    }
    if( $settings['box_animation'] ) {
      $classes[] = $settings['box_animation'];
    }
    if( $settings['text_alignment'] ) {
      $classes[] = $settings['text_alignment'];
    }
    if( $settings['add_bg_img_on_hover'] === 'yes' ) {
      $classes[] = 'iconbox-bg-img-on-hover' ;

      if( $settings['make_bg_img_always_visible'] === 'yes' ) {
        $classes[] = 'iconbox-bg-img-on-hover-always-visible' ;
      }
    }
    if( $settings['box_shadow'] === 'yes' ) {
      $classes[] = 'iconbox-box-shadow' ;
    }
    if( $settings['box_shadow_on_hover'] === 'yes' ) {
      $classes[] = 'iconbox-box-shadow-on-hover' ;
    }
    if( $settings['box_default_padding'] === 'yes' ) {
      $classes[] = 'iconbox-default-padding';
    }
    if( $settings['everything_centered_in_responsive'] === 'yes' ) {
      $classes[] = 'iconbox-centered-in-responsive';
    }
    if( $settings['title_mt_0_in_desktop'] === 'yes' ) {
      $classes[] = 'iconbox-title-mt-0-desktop';
    }
    if( $settings['iconbox_hover_move_up_animation'] === 'yes' ) {
      $classes[] = 'iconbox-hover-move-up-animation';
    }
    if( $settings['iconbox_border_radius'] === 'yes' ) {
      $classes[] = 'iconbox-border-radius';
    }
    if( $settings['icon_theme_colored'] ) {
      $classes[] = 'iconbox-theme-colored' . $settings['icon_theme_colored'];
    }
    if( $settings['icon_position'] ) {
      $classes[] = 'icon-position-' . $settings['icon_position'];
    }
    if( $settings['icon_position'] == 'icon-top' && $settings['icon_hanging_on_top'] === 'yes' ) {
      $classes[] = 'hanging-icon-top';
    }
    if( $settings['animate_icon_on_hover'] ) {
      $classes[] = 'animate-icon-on-hover animate-icon-'.$settings['animate_icon_on_hover'];
    }
    if( $settings['icon_box_shadow'] === 'yes' ) {
      $classes[] = 'icon-area-box-shadow';
    }

    $settings['classes'] = $classes;


    //icon classes
    $icon_classes = array();
    if( $settings['icon_size'] ) {
      $icon_classes[] = $settings['icon_size'];
    }
    if( $settings['icon_color'] ) {
      $icon_classes[] = $settings['icon_color'];
    }
    if( $settings['icon_style'] ) {
      $icon_classes[] = $settings['icon_style'];
    }
    if( $settings['icon_border_style'] === 'yes' ) {
      $icon_classes[] = 'icon-bordered';
    }
    $settings['icon_classes'] = $icon_classes;

    //button classes
    $settings['btn_classes'] = novio_mascot_prepare_button_classes_from_params( $settings );

    //title classes
    $title_classes = array();
    $title_classes[] = $settings['title_custom_css_class'];
    $settings['title_classes'] = $title_classes;

    //icon classes
    $icon_classes = array();
    $icon_classes[] = $settings['icon_custom_css_class'];
    $settings['icon_classes'] = $icon_classes;

    $settings['title_inline_css'] = novio_mascot_get_inline_css( novio_mascot_sc_icon_box_title_css( $settings ) );
    $settings['icon_parent_inline_css'] = novio_mascot_get_inline_css( novio_mascot_sc_icon_box_icon_parent_css( $settings ) );
    $settings['icon_child_inline_css'] = novio_mascot_get_inline_css( novio_mascot_sc_icon_box_icon_child_css( $settings ) );

    $settings['svg_animation_data'] = '';
    if (!empty($settings['svg_source_code'])) {
          $settings['svg_animation_data'] =novio_mascot_sc_icon_svg_animation_data($settings);
    }
    $settings['settings'] = $settings;

    //Produce HTML version by using the parameters (filename, variation, folder name, parameters, shortcode_ob_start)
    $html = mascot_core_novio_elementor_get_shortcode_template_part( 'icon-box-' . $settings['icon_position'], null, 'icon-box/tpl', $settings, true );

    echo $html;
  }
}
