<?php
namespace MascotCoreNovioElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class TM_Elementor_Image_With_Rotated_Text extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'tm-ele-image-with-rotated-text';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Image With Rotated Text', 'mascot-core-elementor' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'tm' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'mascot-core-hellojs' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {

			$this->start_controls_section(
					'general',
					[
							'label' => esc_html__( 'General', 'mascot-core-elementor' ),
							'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
					]
			);
			$this->add_control(
					'custom_css_class',
					[
							'label' => esc_html__( "Custom CSS class", 'mascot-core-elementor' ),
							'type' => \Elementor\Controls_Manager::TEXT,
					]
			);
			$this->add_control(
					'image',
					[
							'label' => esc_html__( "Image", 'mascot-core-elementor' ),
							'type' => \Elementor\Controls_Manager::MEDIA,
					]
			);
			$this->add_control(
					'image_size',
					[
							'label' => esc_html__( "Choose Predefined Image Size", 'mascot-core-elementor' ),
							'type' => \Elementor\Controls_Manager::SELECT,
							'options' => mascot_core_novio_elementor_get_available_image_sizes(),
							'default' => 'full',
							'condition' => [
									'icon_type' => array('image')
							]
					]
			);
			$this->add_control(
					'image_rotate_text',
					[
							'label' => esc_html__( "Text", 'mascot-core-elementor' ),
							'type' => \Elementor\Controls_Manager::TEXT,
					]
			);
			$this->add_control(
					'visible_mobile',
					[
							'label' => esc_html__( "Visible on Mobile Devices?", 'mascot-core-elementor' ),
							'type' => \Elementor\Controls_Manager::SWITCHER,
							'default' => 'yes',
					]
			);
			$this->add_control(
					'enable_textillate_animation',
					[
							'label' => esc_html__( "Enable Text Textillate Animation on Text?", 'mascot-core-elementor' ),
							'type' => \Elementor\Controls_Manager::SWITCHER,
							'default' => 'yes',
					]
			);
			$this->add_control(
					'show_stroke_text',
					[
							'label' => esc_html__( "Show Stroke in Text?", 'mascot-core-elementor' ),
							'type' => \Elementor\Controls_Manager::SWITCHER,
							'default' => 'no',
					]
			);

			$this->end_controls_section();




			$this->start_controls_section(
				'paroller_styling',
				[
					'label' => esc_html__( 'Text Styling', 'mascot-core-elementor' ),
					'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
				]
			);
			$this->add_control(
					'text_position',
					[
							'label' => esc_html__( "Text Position", 'mascot-core-elementor' ),
							'type' => \Elementor\Controls_Manager::SELECT,
							'options' => [
								'top-left'      => esc_html__( 'Top Left', 'mascot-core-elementor' ),
								'bottom-left' => esc_html__( 'Bottom Left', 'mascot-core-elementor' ),
								'top-right'      => esc_html__( 'Top Right', 'mascot-core-elementor' ),
								'bottom-right' => esc_html__( 'Bottom Right', 'mascot-core-elementor' )
							],
							'default' => 'top-left',
					]
			);
			$this->add_control(
				'rotate_text',
				[
					'label' => __( 'Rotate', 'mascot-core-elementor' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ '%' ],
					'range' => [
						'deg' => [
							'min' => -90,
							'max' => 90,
							'step' => 1,
						],
					],
					'default' => [
						'unit' => 'deg',
						'size' => -90,
					],
				]
			);
			$this->add_control(
				'pos_top',
				[
					'label' => esc_html__( "Top (px or %)", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::TEXT,
				]
			);
			$this->add_control(
				'pos_right',
				[
					'label' => esc_html__( "Right (px or %)", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::TEXT,
				]
			);
			$this->add_control(
				'pos_bottom',
				[
					'label' => esc_html__( "Bottom (px or %)", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::TEXT,
				]
			);
			$this->add_control(
				'pos_left',
				[
					'label' => esc_html__( "Left (px or %)", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::TEXT,
				]
			);
			$this->add_control(
				'title_text_color',
				[
					'label' => esc_html__( "Text Color", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::COLOR,
				]
			);
			$this->add_control(
				'text_stroke_size',
				[
					'label' => __( 'Text Stroke Size', 'mascot-core-elementor' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ 'px' ],
					'range' => [
						'px' => [
							'min' => 1,
							'max' => 30,
						],
					],
					'default' => [
						'unit' => 'px',
						'size' => 2,
					],
					'condition' => [
						'show_stroke_text' => array('yes'),
					]
				]
			);
			$this->add_control(
				'title_font_size',
				[
					'label' => esc_html__( "Font Size", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::TEXT,
				]
			);
			$this->add_control(
				'title_line_height',
				[
					'label' => esc_html__( "Line Height", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::TEXT,
				]
			);
			$this->add_control(
				'title_letter_spacing',
				[
					'label' => esc_html__( "Letter Spacing", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::TEXT,
				]
			);
			$this->add_control(
				'title_font_style',
				[
					'label' => esc_html__( "Font Style", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'options' => mascot_core_novio_elementor_font_style_list(),
				]
			);
			$this->add_control(
				'title_font_weight',
				[
					'label' => esc_html__( "Font Weight", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'options' => mascot_core_novio_elementor_font_weight_list(),
				]
			);
			$this->add_control(
				'title_text_transform',
				[
					'label' => esc_html__( "Text Transform", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::SELECT,
					'options' => mascot_core_novio_elementor_text_transform_list(),
				]
			);
			$this->add_control(
				'z_index',
				[
					'label' => esc_html__( "Z Index", 'mascot-core-elementor' ),
					'type' => \Elementor\Controls_Manager::TEXT,
				]
			);
			$this->add_control(
				'opacity',
				[
					'label' => __( 'Opacity', 'mascot-core-elementor' ),
					'type' => Controls_Manager::SLIDER,
					'size_units' => [ '%' ],
					'range' => [
						'%' => [
							'min' => 0,
							'max' => 100,
						],
					],
					'default' => [
						'unit' => '%',
						'size' => 50,
					],
				]
			);
			$this->end_controls_section();

	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		
		//classes
		$classes = array();
		$classes[] = $settings['custom_css_class'];
		if( $settings['text_position'] != '' ) {
			$classes[] = 'text-position-'.$settings['text_position'];
		}
		if ( $settings['visible_mobile'] != 'yes' ) {
			$classes[] = 'd-none d-lg-block';
		}
		$settings['classes'] = $classes;
		$settings['text_inline_css'] = $this->inline_css( $settings );

		$settings['text_class'] = '';
		if ( $settings['enable_textillate_animation'] == 'yes' ) {
			$settings['text_class'] = 'tm-textillate-animation';
		}

		//Produce HTML version by using the parameters (filename, variation, folder name, parameters, shortcode_ob_start)
		$html = mascot_core_novio_elementor_get_shortcode_template_part( 'image-with-rotated-text', null, 'image-with-rotated-text/tpl', $settings, true );

		echo $html;
	}


	/**
	 * Get Wrapper Styles
	 */
	protected function inline_css( $params ) {
		$css_array = array();

		if( !empty($params['rotate_text']['size']) &&$params['rotate_text']['size'] != '90' && $params['rotate_text']['size'] != '0' ) {
			$css_array[] = '-webkit-transform: rotate('.$params['rotate_text']['size'].'deg)';
			$css_array[] = '-ms-transform: rotate('.$params['rotate_text']['size'].'deg)';
			$css_array[] = 'transform: rotate('.$params['rotate_text']['size'].'deg)';
		}

		if( $params['pos_top'] != '' ) {
			$css_array[] = 'top: '.$params['pos_top'];
		}
		if( $params['pos_right'] != '' ) {
			$css_array[] = 'right: '.$params['pos_right'];
		}
		if( $params['pos_bottom'] != '' ) {
			$css_array[] = 'bottom: '.$params['pos_bottom'];
		}
		if( $params['pos_left'] != '' ) {
			$css_array[] = 'left: '.$params['pos_left'];
		}


		if( $params['show_stroke_text'] != 'yes' && $params['title_text_color'] != '' ) {
			$css_array[] = 'color: '.$params['title_text_color'];
		}
		if( $params['title_font_size'] != '' ) {
			$font_size = $params['title_font_size'];
			$css_array[] = 'font-size: '.novio_mascot_if_numeric_add_suffix($font_size, 'px');
		}
		if( $params['title_line_height'] != '' ) {
			$line_height = $params['title_line_height'];
			$css_array[] = 'line-height: '.$line_height;
		}
		if( $params['title_letter_spacing'] != '' ) {
			$letter_spacing = $params['title_letter_spacing'];
			$css_array[] = 'letter-spacing: '.$letter_spacing;
		}
		if( $params['title_font_style'] != '' ) {
			$css_array[] = 'font-style: '.$params['title_font_style'];
		}
		if( $params['title_font_weight'] != '' ) {
			$css_array[] = 'font-weight: '.$params['title_font_weight'];
		}
		if( $params['title_text_transform'] != '' ) {
			$css_array[] = 'text-transform: '.$params['title_text_transform'];
		}
		if( $params['z_index'] != '' ) {
			$css_array[] = 'z-index: '.$params['z_index'];
		}

		if( $params['opacity'] != '' ) {
			$css_array[] = 'opacity: '.$params['opacity']['size']*0.01;
		}
		if ( $params['show_stroke_text'] != 'yes' ) {
			$css_array[] = '-webkit-text-stroke: unset';
		}
		if( $params['show_stroke_text'] == 'yes' && $params['title_text_color'] != '' ) {
			$css_array[] = '-webkit-text-stroke: '.$params['text_stroke_size']['size'].'px '.$params['title_text_color'];
		}

		$css_array = implode( '; ', $css_array ).';';

		return $css_array;
	}
}
