<?php
namespace MascotCoreNovioElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class TM_Elementor_Pricing_Table extends Widget_Base {

	/**
	 * Retrieve the widget name.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'tm-ele-pricing-table';
	}

	/**
	 * Retrieve the widget title.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Pricing Table', 'mascot-core-elementor' );
	}

	/**
	 * Retrieve the widget icon.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-posts-ticker';
	}

	/**
	 * Retrieve the list of categories the widget belongs to.
	 *
	 * Used to determine where to display the widget in the editor.
	 *
	 * Note that currently Elementor supports only one category.
	 * When multiple categories passed, Elementor uses the first one.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'tm' ];
	}

	/**
	 * Retrieve the list of scripts the widget depended on.
	 *
	 * Used to set scripts dependencies required to run the widget.
	 *
	 * @since 1.0.0
	 *
	 * @access public
	 *
	 * @return array Widget scripts dependencies.
	 */
	public function get_script_depends() {
		return [ 'mascot-core-hellojs' ];
	}

	/**
	 * Register the widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function register_controls() {

		$this->start_controls_section(
			'general',
			[
				'label' => esc_html__( 'General', 'mascot-core-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
				'default' => ''
			]
		);
		$this->add_control(
			'custom_css_class',
			[
				'label' => esc_html__( "Custom CSS class", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
			]
		);
		$this->add_control(
			'design_style',
			[
				'label' => esc_html__( "Design Style", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'style1' => esc_html__( 'Style 1 - Current Theme Design', 'mascot-core-elementor' ),
					'style2' => esc_html__( 'Style 2 - Padding Around Whole Table', 'mascot-core-elementor' ),
					'style3' => esc_html__( 'Style 3 - Padding + Title Area Text Center', 'mascot-core-elementor' ),
					'style4' => esc_html__( 'Style 4 - Padding + Everything Text Center', 'mascot-core-elementor' ),
					'style5' => esc_html__( 'Style 5 - No Padding + Everything Text Center', 'mascot-core-elementor' ),
				],
				'default' => 'style1'
			]
		);
		$this->add_control(
			'pricing_image',
			[
				'label' => esc_html__( "Pricing Thumbnail Image", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				'description' => esc_html__( "This image will be shown on the top of the pricing table", 'mascot-core-elementor' ),
			]
		);
		$this->add_control(
			'title',
			[
				'label' => esc_html__( "Title", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => ''
			]
		);
		$this->add_control(
			'sub_title',
			[
				'label' => esc_html__( "Sub Title", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => ''
			]
		);
		$this->add_control(
			'price_prefix',
			[
				'label' => esc_html__( "Prefix", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => ''
			]
		);
		$this->add_control(
			'price',
			[
				'label' => esc_html__( "Price", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => ''
			]
		);
		$this->add_control(
			'price_separator',
			[
				'label' => esc_html__( "Separator", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => ''
			]
		);
		$this->add_control(
			'price_postfix',
			[
				'label' => esc_html__( "Postfix", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => ''
			]
		);
		$this->add_control(
			'label_text',
			[
				'label' => esc_html__( "Label/Offer/Tag Text", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => ''
			]
		);
		$this->add_control(
			'content',
			[
				'label' => esc_html__( "Text", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::WYSIWYG,
				'default' => ''
			]
		);
		$this->end_controls_section();



		$this->start_controls_section(
			'title_options',
			[
				'label' => esc_html__( 'Title Options', 'mascot-core-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'title_custom_css_class',
			[
				'label' => esc_html__( "Title Custom CSS Class", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'description' => esc_html__( "To style Title", 'mascot-core-elementor' ),
			]
		);
		$this->add_control(
			'title_tag',
			[
				'label' => esc_html__( "Title Tag", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
        'options' => novio_mascot_heading_tag_list(),
				'default' => 'h2'
			]
		);
		$this->add_control(
			'title_text_color',
			[
				'label' => esc_html__( "Text Color", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'description' => esc_html__( "The color of the curcular bar. Leave empty for default value", 'mascot-core-elementor' ),
				'default' => ''
			]
		);
		$this->add_control(
			'title_font_size',
			[
				'label' => esc_html__( "Font Size", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => ''
			]
		);
		$this->add_control(
			'title_line_height',
			[
				'label' => esc_html__( "Line Height", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => ''
			]
		);
		$this->add_control(
			'title_letter_spacing',
			[
				'label' => esc_html__( "Letter Spacing", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => ''
			]
		);
		$this->add_control(
			'title_font_style',
			[
				'label' => esc_html__( "Font Style", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
        'options' => mascot_core_novio_elementor_font_style_list(),
			]
		);
		$this->add_control(
			'title_font_weight',
			[
				'label' => esc_html__( "Font Weight", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
        'options' => mascot_core_novio_elementor_font_weight_list(),
			]
		);
		$this->add_control(
			'title_text_transform',
			[
				'label' => esc_html__( "Text Transform", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
        'options' => mascot_core_novio_elementor_text_transform_list(),
			]
		);
		$this->end_controls_section();



		$this->start_controls_section(
			'sub_title_options',
			[
				'label' => esc_html__( 'Sub Title Options', 'mascot-core-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'subtitle_custom_css_class',
			[
				'label' => esc_html__( "Sub Title Custom CSS Class", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( "WordPress", 'mascot-core-elementor' )
			]
		);
		$this->add_control(
			'subtitle_tag',
			[
				'label' => esc_html__( "Sub Title Tag", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
        'options' => novio_mascot_heading_tag_list(),
				'default' => 'h5'
			]
		);
		$this->add_control(
			'subtitle_text_color',
			[
				'label' => esc_html__( "Text Color", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'description' => esc_html__( "The color of the curcular bar. Leave empty for default value", 'mascot-core-elementor' ),
				'default' => ''
			]
		);
		$this->add_control(
			'subtitle_font_size',
			[
				'label' => esc_html__( "Font Size", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => ''
			]
		);
		$this->add_control(
			'subtitle_line_height',
			[
				'label' => esc_html__( "Line Height", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => ''
			]
		);
		$this->add_control(
			'subtitle_letter_spacing',
			[
				'label' => esc_html__( "Letter Spacing", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => ''
			]
		);
		$this->add_control(
			'subtitle_font_style',
			[
				'label' => esc_html__( "Font Style", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
         'options' => mascot_core_novio_elementor_font_style_list(),
			]
		);
		$this->add_control(
			'subtitle_font_weight',
			[
				'label' => esc_html__( "Font Weight", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
        'options' => mascot_core_novio_elementor_font_weight_list(),
			]
		);
		$this->add_control(
			'subtitle_text_transform',
			[
				'label' => esc_html__( "Text Transform", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
        'options' => mascot_core_novio_elementor_text_transform_list(),
			]
		);
		$this->end_controls_section();



		$this->start_controls_section(
			'price_options',
			[
				'label' => esc_html__( 'Price Options', 'mascot-core-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'price_text_color',
			[
				'label' => esc_html__( "Price Text Color", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'default' => ''
			]
		);
		$this->add_control(
			'price_font_size',
			[
				'label' => esc_html__( "Price Font Size", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => ''
			]
		);
		$this->add_control(
			'price_line_height',
			[
				'label' => esc_html__( "Price Line Height", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => ''
			]
		);
		$this->add_control(
			'price_letter_spacing',
			[
				'label' => esc_html__( "Price Letter Spacing", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => ''
			]
		);
		$this->add_control(
			'price_font_style',
			[
				'label' => esc_html__( "Price Font Style", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
        'options' => mascot_core_novio_elementor_font_style_list(),
			]
		);
		$this->add_control(
			'price_font_weight',
			[
				'label' => esc_html__( "Price Font Weight", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
        'options' => mascot_core_novio_elementor_font_weight_list(),
			]
		);
		$this->add_control(
			'price_text_transform',
			[
				'label' => esc_html__( "Price Text Transform", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
        'options' => mascot_core_novio_elementor_text_transform_list(),
			]
		);
		$this->end_controls_section();



		$this->start_controls_section(
			'features',
			[
				'label' => esc_html__( 'Features', 'mascot-core-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'disable_list_bullets',
			[
				'label' => esc_html__( "Disable List(ul, li) Bullets Icons in Content Text Area?", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
		$this->add_control(
			'list_bordered',
			[
				'label' => esc_html__( "Make List(ul, li) Border Bottom?", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
		$this->add_control(
			'put_pricing_info_after_text',
			[
				'label' => esc_html__( "Put Pricing Info after Content/Text Block?", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'default' => 'no',
			]
		);
		$this->add_control(
			'put_pricing_image_after_title',
			[
				'label' => esc_html__( "Put Pricing Thumbnail Image after Title/Subtitle?", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'default' => 'no',
			]
		);
		$this->add_control(
			'add_box_shadow_around_table',
			[
				'label' => esc_html__( "Add Box Shadow Around Table?", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);
		$this->add_control(
			'make_this_table_featured',
			[
				'label' => esc_html__( "Make This Table Featured?", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'description' => esc_html__( "Featured Pricing Table has some different looks to highlight it", 'mascot-core-elementor' ),
				'default' => 'no',
			]
		);
		$this->add_control(
			'make_hover_effect',
			[
				'label' => esc_html__( "Make Hover Effect on This Table?", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'default' => 'yes',
				'description' => esc_html__( "There will be a transition when hovering on this table", 'mascot-core-elementor' ),
			]
		);
		$this->end_controls_section();










    $this->start_controls_section(
        'button_options',
        [
            'label' => esc_html__( 'Button Options', 'mascot-core-elementor' ),
            'tab'   => \Elementor\Controls_Manager::TAB_CONTENT,
        ]
    );
    $this->add_control(
        'link',
        [
          'label' => esc_html__( "Link URL", 'mascot-core-elementor' ),
          'type' => \Elementor\Controls_Manager::URL,
          'show_external' => true,
          'default' => [
            'url' => '',
            'is_external' => true,
            'nofollow' => true,
          ],
          'condition' => [
              'link_icon_title' => array('yes')
          ]
        ]
    );
    mascot_core_novio_elementor_get_viewdetails_button_arraylist($this, 1);
    mascot_core_novio_elementor_get_viewdetails_button_arraylist($this, 2);
    mascot_core_novio_elementor_get_button_arraylist($this, 1);
    mascot_core_novio_elementor_get_button_arraylist($this, 2);
    mascot_core_novio_elementor_get_button_arraylist($this, 3);
    mascot_core_novio_elementor_get_button_arraylist($this, 4);
    mascot_core_novio_elementor_get_button_arraylist($this, 5);
    mascot_core_novio_elementor_get_button_arraylist($this, 6);
    mascot_core_novio_elementor_get_button_arraylist($this, 7);
    mascot_core_novio_elementor_get_button_arraylist($this, 8);
    mascot_core_novio_elementor_get_button_arraylist($this, 9);
    mascot_core_novio_elementor_get_button_arraylist($this, 10);
    mascot_core_novio_elementor_get_button_arraylist($this, 11);
    $this->end_controls_section();




	}

	/**
	 * Render the widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 *
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		
		//link url
    $settings['button']['target'] = $settings['link']['is_external'] ? ' target="_blank"' : '';
    $settings['button']['url'] = $settings['link']['url'];

		//classes
		$classes = array();
		$classes[] = (!empty($settings['label_text']) ) ? 'has-label' : '';

		$classes[] = 'pricing-table-' . $settings['design_style'];

		if( ! $settings['disable_list_bullets'] ) {
			$classes[] = 'pricing-list-bullet';
		}
		if( $settings['list_bordered'] ) {
			$classes[] = 'pricing-list-bordered';
		}
		if( $settings['make_this_table_featured'] ) {
			$classes[] = 'pricing-table-featured';
		}
		if( $settings['make_hover_effect'] ) {
			$classes[] = 'pricing-table-hover-effect';
		}
		if( $settings['add_box_shadow_around_table'] ) {
			$classes[] = 'pricing-table-box-shadow';
		}

		$classes[] = $settings['custom_css_class'];
		$settings['classes'] = $classes;
		$settings['title_inline_css'] = novio_mascot_get_inline_css( novio_mascot_sc_pricing_table_title_css( $settings ) );
		$settings['subtitle_inline_css'] = novio_mascot_get_inline_css( novio_mascot_sc_pricing_table_subtitle_css( $settings ) );
		$settings['price_inline_css'] = novio_mascot_get_inline_css( novio_mascot_sc_pricing_table_price_css( $settings ) );

		//button classes
		$settings['btn_classes'] = novio_mascot_prepare_button_classes_from_params( $settings );

		//title classes
		$title_classes = array();
		$title_classes[] = $settings['title_custom_css_class'];
		$settings['title_classes'] = $title_classes;
		
		//sub title classes
		$sub_title_classes = array();
		$sub_title_classes[] = $settings['subtitle_custom_css_class'];
		$settings['sub_title_classes'] = $sub_title_classes;

    $settings['settings'] = $settings;

		//Produce HTML version by using the parameters (filename, variation, folder name, parameters, shortcode_ob_start)
		$html = mascot_core_novio_elementor_get_shortcode_template_part( 'pricing-table', $settings['design_style'], 'pricing-table/tpl', $settings, true );

		echo $html;
	}
}
