<?php
namespace MascotCoreNovioElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class TM_Elementor_Unordered_List extends Widget_Base {

  /**
   * Retrieve the widget name.
   *
   * @since 1.0.0
   *
   * @access public
   *
   * @return string Widget name.
   */
  public function get_name() {
    return 'tm-ele-unordered-list';
  }

  /**
   * Retrieve the widget title.
   *
   * @since 1.0.0
   *
   * @access public
   *
   * @return string Widget title.
   */
  public function get_title() {
    return __( 'Unordered List', 'mascot-core-elementor' );
  }

  /**
   * Retrieve the widget icon.
   *
   * @since 1.0.0
   *
   * @access public
   *
   * @return string Widget icon.
   */
  public function get_icon() {
    return 'eicon-posts-ticker';
  }

  /**
   * Retrieve the list of categories the widget belongs to.
   *
   * Used to determine where to display the widget in the editor.
   *
   * Note that currently Elementor supports only one category.
   * When multiple categories passed, Elementor uses the first one.
   *
   * @since 1.0.0
   *
   * @access public
   *
   * @return array Widget categories.
   */
  public function get_categories() {
    return [ 'tm' ];
  }

  /**
   * Retrieve the list of scripts the widget depended on.
   *
   * Used to set scripts dependencies required to run the widget.
   *
   * @since 1.0.0
   *
   * @access public
   *
   * @return array Widget scripts dependencies.
   */
  public function get_script_depends() {
    return [ 'mascot-core-hellojs' ];
  }

  /**
   * Register the widget controls.
   *
   * Adds different input fields to allow the user to change and customize the widget settings.
   *
   * @since 1.0.0
   *
   * @access protected
   */
  protected function register_controls() {

      $this->start_controls_section(
          'general',
          [
              'label' => esc_html__( 'General', 'mascot-core-elementor' ),
              'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
          ]
      );
      $this->add_control(
          'custom_css_class',
          [
              'label' => esc_html__( "Custom CSS class", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXT,
          ]
      );
      $this->add_control(
          'unordered_list_style',
          [
              'label' => esc_html__( "Design Style", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SELECT,
              'description' => '',
              'options' => [
                  'list-default'  =>  esc_html__( 'Default', 'mascot-core' ),
                  'list-style23'  =>  esc_html__( 'Style 23 Tick + Circle', 'mascot-core' ),
                  'list-style2' =>  esc_html__( 'Style 2', 'mascot-core' ),
                  'list-style3' =>  esc_html__( 'Style 3', 'mascot-core' ),
                  'list-style4' =>  esc_html__( 'Style 4', 'mascot-core' ),
                  'list-style5' =>  esc_html__( 'Style 5', 'mascot-core' ),
                  'list-style6' =>  esc_html__( 'Style 6', 'mascot-core' ),
                  'list-style7' =>  esc_html__( 'Style 7', 'mascot-core' ),
                  'list-style8' =>  esc_html__( 'Style 8', 'mascot-core' ),
                  'list-style9' =>  esc_html__( 'Style 9', 'mascot-core' ),
                  'list-style10'  =>  esc_html__( 'Style 10', 'mascot-core' ),
                  'list-style11'  =>  esc_html__( 'Style 11', 'mascot-core' ),
                  'list-style12'  =>  esc_html__( 'Style 12', 'mascot-core' ),
                  'list-style13'  =>  esc_html__( 'Style 13', 'mascot-core' ),
                  'list-style14'  =>  esc_html__( 'Style 14', 'mascot-core' ),
                  'list-style15'  =>  esc_html__( 'Style 15', 'mascot-core' ),
                  'list-style16'  =>  esc_html__( 'Style 16', 'mascot-core' ),
                  'list-style17'  =>  esc_html__( 'Style 17', 'mascot-core' ),
                  'list-style18'  =>  esc_html__( 'Style 18', 'mascot-core' ),
                  'list-style19'  =>  esc_html__( 'Style 19', 'mascot-core' ),
                  'list-style20'  =>  esc_html__( 'Style 20', 'mascot-core' ),
                  'list-style21'  =>  esc_html__( 'Style 21', 'mascot-core' ),
                  'list-style22'  =>  esc_html__( 'Style 22', 'mascot-core' ),
              ],
              'default' => 'list-default',
          ]
      );
      $this->add_control(
          'content',
          [
              'label' => esc_html__( "Content", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::WYSIWYG,
              'default' => "<ul><li>List item one</li><li>List item two</li><li>List item three</li><li>List item four</li></ul>",
          ]
      );

      $this->add_control(
          'title_text_color',
          [
              'label' => esc_html__( "Text Color", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::COLOR,
          ]
      );
      $this->add_control(
          'title_font_size',
          [
              'label' => esc_html__( "Font Size", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXT,
          ]
      );
      $this->add_control(
          'title_line_height',
          [
              'label' => esc_html__( "Line Height", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXT,
          ]
      );
      $this->add_control(
          'title_letter_spacing',
          [
              'label' => esc_html__( "Letter Spacing", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::TEXT,
          ]
      );
      $this->add_control(
          'title_font_style',
          [
              'label' => esc_html__( "Font Style", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SELECT,
              'options' => mascot_core_novio_elementor_font_style_list(),
          ]
      );
      $this->add_control(
          'title_font_weight',
          [
              'label' => esc_html__( "Font Weight", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SELECT,
              'options' => mascot_core_novio_elementor_font_weight_list(),
          ]
      );
      $this->add_control(
          'title_text_transform',
          [
              'label' => esc_html__( "Text Transform", 'mascot-core-elementor' ),
              'type' => \Elementor\Controls_Manager::SELECT,
              'options' => mascot_core_novio_elementor_text_transform_list(),
          ]
      );
      $this->end_controls_section();
  }

  /**
   * Render the widget output on the frontend.
   *
   * Written in PHP and used to generate the final HTML.
   *
   * @since 1.0.0
   *
   * @access protected
   */
  protected function render() {
    $settings = $this->get_settings_for_display();

    $settings['text_inline_css'] = $this->inline_css( $settings );

    //classes
    $classes = array();
    $classes[] = 'tm-sc tm-sc-unordered-list';
    $classes[] = $settings['custom_css_class'];
    $classes[] = $settings['unordered_list_style'];

    $settings['classes'] = $classes;

    //Produce HTML version by using the parameters (filename, variation, folder name, parameters, shortcode_ob_start)
    $html = mascot_core_novio_elementor_get_shortcode_template_part( 'unordered-list', null, 'unordered-list/tpl', $settings, true );

    echo $html;
  }


  /**
   * Get Wrapper Styles
   */
  protected function inline_css( $params ) {
    $css_array = array();
    if( $params['title_font_size'] != '' ) {
      $font_size = $params['title_font_size'];
      $css_array[] = 'font-size: '.novio_mascot_if_numeric_add_suffix($font_size, 'px');
    }
    if( $params['title_line_height'] != '' ) {
      $line_height = $params['title_line_height'];
      $css_array[] = 'line-height: '.$line_height;
    }
    if( $params['title_letter_spacing'] != '' ) {
      $letter_spacing = $params['title_letter_spacing'];
      $css_array[] = 'letter-spacing: '.$letter_spacing;
    }
    if( $params['title_font_style'] != '' ) {
      $css_array[] = 'font-style: '.$params['title_font_style'];
    }
    if( $params['title_font_weight'] != '' ) {
      $css_array[] = 'font-weight: '.$params['title_font_weight'];
    }
    if( $params['title_text_transform'] != '' ) {
      $css_array[] = 'text-transform: '.$params['title_text_transform'];
    }

    $css_array = implode( '; ', $css_array ).';';

    return $css_array;
  }
}